==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/CORRECTIONSCORERANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CORRECTIONSCORERANKINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CORRECTIONSCORERANKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONSCORERANKINCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONSCORERANKINREVISION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CORRECTIONSCORERANKINGID_Type", propOrder = {
    "correctionscorerankincode",
    "organizationid",
    "correctionscorerankinrevision"
})
public class CORRECTIONSCORERANKINGID_Type {

    @XmlElement(name = "CORRECTIONSCORERANKINCODE")
    protected String correctionscorerankincode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CORRECTIONSCORERANKINREVISION")
    protected Long correctionscorerankinrevision;

    /**
     * Gets the value of the correctionscorerankincode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCORRECTIONSCORERANKINCODE() {
        return correctionscorerankincode;
    }

    /**
     * Sets the value of the correctionscorerankincode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCORRECTIONSCORERANKINCODE(String value) {
        this.correctionscorerankincode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the correctionscorerankinrevision property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getCORRECTIONSCORERANKINREVISION() {
        return correctionscorerankinrevision;
    }

    /**
     * Sets the value of the correctionscorerankinrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setCORRECTIONSCORERANKINREVISION(Long value) {
        this.correctionscorerankinrevision = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/CORRECTIONSCORERANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CORRECTIONSCORERANKINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CORRECTIONSCORERANKINGID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONSCORERANKINCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONSCORERANKINREVISION" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CORRECTIONSCORERANKINGID_Type", propOrder = {
    "correctionscorerankincode",
    "organizationid",
    "correctionscorerankinrevision"
})
public class CORRECTIONSCORERANKINGID_Type {

    @XmlElement(name = "CORRECTIONSCORERANKINCODE")
    protected String correctionscorerankincode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CORRECTIONSCORERANKINREVISION")
    protected Long correctionscorerankinrevision;

    /**
     * Gets the value of the correctionscorerankincode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCORRECTIONSCORERANKINCODE() {
        return correctionscorerankincode;
    }

    /**
     * Sets the value of the correctionscorerankincode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCORRECTIONSCORERANKINCODE(String value) {
        this.correctionscorerankincode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the correctionscorerankinrevision property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getCORRECTIONSCORERANKINREVISION() {
        return correctionscorerankinrevision;
    }

    /**
     * Sets the value of the correctionscorerankinrevision property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setCORRECTIONSCORERANKINREVISION(Long value) {
        this.correctionscorerankinrevision = value;
    }

}
